@@ -44,7 +44,7 @@ class RudderstackSerializer(SinkSerializer):
             "event_name": "$experiment_started",
             "properties": {
                 'Experiment name': element['feature'],
-                'Variant name': element['variant']['name']
+                'Variant name': element['variant']['name'],
             },
             "timestamp": datetime.now(),
             # "integrations": {
@@ -83,7 +83,7 @@ class RudderstackSink(Sink):
             logging.warning(
                 f'Ruddersink is already initialized. To recreate instance, you need to destroy exisiting one first.')
 
-    def push(self, element: dict) -> bool:
+    def push(self, element: dict, **kwargs) -> bool:
         """This method calls the 'track' method of the rudderstack clients.
         It requires 'user_id', 'event' and 'properties'.
 
@@ -93,7 +93,7 @@ class RudderstackSink(Sink):
         Returns:
             bool: Returns true if success.
         """
-        serialized_data = self.serializer.serialize(element)
+        serialized_data = self.serializer.serialize(element, **kwargs)
 
         try:
             self.client.track(
